LasserreAvrachenkov implements the exact integration formula for a homogeneous polynomial p of degree q. The other functions are helper functions for that.
LasserreAvrachenkov(q, p, useTerm, S)
nextIndexLA(current.n, b)
nextIntBaseB(current.n, b)degree of the polynomial p
polynomial obtained by calling definePoly
vector of booleans, telling which terms are homogeneous of degree q
an n x (n+1) matrix specifying a single simplex; the columns S[,1],..,S[,n+1] give the vertices of the simplex.
vector of integers giving the base b representation of a (non-negative) integer
base used for the base b representation of an integer
Not meant to be called externally.
See Lasserre and Avrachenkov, Baldoni, et al., and Konerth references in SimplicialCubature-package.