SimplicialCubature-package: Numerical integration of functions over simplices
Description
This package provides methods to evaluate integrals of the form
$$\int_S f(x) dx,$$
where S is a simplex (or a union of simplices) in n-space and f(x) is a function defined on S.
The function f(x) may be vector valued and the simplices can be m-dimensional simplices,
1 <= m="" <="n." for="" example,="" if="" the="" package="" will="" evaluate="" a="" surface="" area="" integral;="" line="" integral.="" there="" are="" exact="" methods="" polynomials="" and="" adaptive="" integrating="" an="" arbitrary="" function.="" two="" main="" functions="" are:="" adaptIntegrateSimplex - integrate a general (possibly vector valued)
function over a simplex using the method of Genz and Cools.
integrateSimplexPolynomial - integrate a single polynomial exactly over a simplex using either
the Grundmann-Moller method or the Lasserre-Avrachenkov method.
The naming of the functions, arguments, and return values deliberately mimics that in the CRAN packages
cubature (for integrating over hyper-rectangles) and SphericalCubature (for integrating
over spheres and balls).
Please let me know if you find any mistakes. I will try to fix bugs promptly.
Constructive comments for improvements are welcome;
actually implementing any suggestions will be dependent on time constraints.
Version history:
- 1.0.1 (2014-09-09) original package
=>Details
ll{
Package: SimplicialCubature
Type: Package
Version: 1.0
Date: 2014-09-09
License: GPL (>= 2)
}References
V. Baldoni, N. Berline, J. A. De Loera, M. Koppe, and M. Vergene,
How to integrate a polynomial over a simplex, Mathematics of Computation,
80, 297-325 (2011)
A. Genz and R. Cools, An adaptive numerical cubature algorithm for simplices,
ACM Trans. Math. Software, 29, 297-308 (2003)
A. Grundmann and H.M. Moller, Invariant Integration Formulas for the $n$-Simplex by
Combinatorial Methods, SIAM Journal on Numerical Analysis, 15, 282-289 (1978)
J. B. Lasserre and E. E. Avrachenkov, The Multi-Dimensional Version of
$\int^b_a x^p dx$,
American Mathematical Monthly, 108, 151-154 (2001)
N. Konerth, Exact integration on simplices, Undergraduate Research Paper,
Math/Stat Department, American University (2014)