grnmol: Grundmann-Moller integration of a function over a simplex
Description
Computes an approximation to the integral of a function f(x) over a simplex S.
This is an R translation of the matlab function grnmol.m which was written
by Alan Genz.
Usage
grnmol(f,V,s)
Arguments
Value
Qa vector of length s+1, with Q[i] the i-th degree approximate value of the integralnvnumber of function evaluations used
Details
The Grundmann-Moller algorithm approximates the integral of f(x) over the simplex
V. When f(x) is a polynomial, and s is large enough, the integral is exact.
This function is called by integrateSimplexPolynomial.